==> cv-dialog-sdk-4.5.1.tgz: package/src/js/catavolt/storage/ClientStorage.js <==
var ApiType;
(function (ApiType) {
    ApiType[ApiType["LOCAL_STORAGE"] = 0] = "LOCAL_STORAGE";
    ApiType[ApiType["ASYNC_STORAGE"] = 1] = "ASYNC_STORAGE";
})(ApiType || (ApiType = {}));
export const setCvStorageApi = (storageApi) => {
    ClientStorage.setStorageApi(storageApi);
};
class ClientStorage {
    static setStorageApi(storageApi) {
        ClientStorage._storageApi = storageApi;
        if (ClientStorage._storageApi) {
            if (ClientStorage._storageApi.getAllKeys) {
                // Assume AsyncStorage
                ClientStorage._type = ApiType.ASYNC_STORAGE;
            }
            else {
                // Assume window.localStorage
                ClientStorage._type = ApiType.LOCAL_STORAGE;
            }
        }
    }
    getItem(key) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.getItemAsyncStorage(key, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getJson(key) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.getJsonAsyncStorage(key, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    setItem(key, value) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.setItemAsyncStorage(key, value, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    setJson(key, value) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.setJsonAsyncStorage(key, value, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    removeItem(key) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.removeItemAsyncStorage(key, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    clearAll() {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.clearAllAsyncStorage(ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getAllKeys() {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.getAllKeysAsyncStorage(ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    multiRemove(keys) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.multiRemoveAsyncStorage(keys, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getItemAsyncStorage(key, api) {
        return api.getItem(key);
    }
    getJsonAsyncStorage(key, api) {
        return api.getItem(key).then(value => {
            try {
                return JSON.parse(value);
            }
            catch (err) {
                throw new Error(`Storage::getItem('${key}') parse JSON failed for: ${value}`);
            }
        });
    }
    setItemAsyncStorage(key, value, api) {
        return api.setItem(key, value);
    }
    setJsonAsyncStorage(key, value, api) {
        let stringVal = null;
        try {
            stringVal = JSON.stringify(value);
        }
        catch (err) {
            return Promise.reject(new Error(`Storage::setItem(${key}) failed to stringify JSON value`));
        }
        return api.setItem(key, stringVal);
    }
    removeItemAsyncStorage(key, api) {
        return api.removeItem(key);
    }
    clearAllAsyncStorage(api) {
        return api.clear();
    }
    getAllKeysAsyncStorage(api) {
        return api.getAllKeys();
    }
    multiRemoveAsyncStorage(keys, api) {
        return api.multiRemove(keys);
    }
}
// default to window.localStorage
ClientStorage._type = ApiType.LOCAL_STORAGE;
export const storage = new ClientStorage();

==> cv-dialog-sdk-4.14.0.tgz: package/src/js/catavolt/storage/ClientStorage.js <==
var ApiType;
(function (ApiType) {
    ApiType[ApiType["LOCAL_STORAGE"] = 0] = "LOCAL_STORAGE";
    ApiType[ApiType["ASYNC_STORAGE"] = 1] = "ASYNC_STORAGE";
})(ApiType || (ApiType = {}));
export const setCvStorageApi = storageApi => {
    ClientStorage.setStorageApi(storageApi);
};
class ClientStorage {
    static setStorageApi(storageApi) {
        ClientStorage._storageApi = storageApi;
        if (ClientStorage._storageApi) {
            if (ClientStorage._storageApi.getAllKeys) {
                // Assume AsyncStorage
                ClientStorage._type = ApiType.ASYNC_STORAGE;
            }
            else {
                // Assume window.localStorage
                ClientStorage._type = ApiType.LOCAL_STORAGE;
            }
        }
    }
    getItem(key) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.getItemAsyncStorage(key, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getJson(key) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.getJsonAsyncStorage(key, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    setItem(key, value) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.setItemAsyncStorage(key, value, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    setJson(key, value) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.setJsonAsyncStorage(key, value, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    removeItem(key) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.removeItemAsyncStorage(key, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    clearAll() {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.clearAllAsyncStorage(ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getAllKeys() {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.getAllKeysAsyncStorage(ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    multiRemove(keys) {
        if (ClientStorage._type === ApiType.ASYNC_STORAGE) {
            return this.multiRemoveAsyncStorage(keys, ClientStorage._storageApi);
        }
        else if (ClientStorage._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getItemAsyncStorage(key, api) {
        return api.getItem(key);
    }
    getJsonAsyncStorage(key, api) {
        return api.getItem(key).then(value => {
            try {
                return JSON.parse(value);
            }
            catch (err) {
                throw new Error(`Storage::getItem('${key}') parse JSON failed for: ${value}`);
            }
        });
    }
    setItemAsyncStorage(key, value, api) {
        return api.setItem(key, value);
    }
    setJsonAsyncStorage(key, value, api) {
        let stringVal = null;
        try {
            stringVal = JSON.stringify(value);
        }
        catch (err) {
            return Promise.reject(new Error(`Storage::setItem(${key}) failed to stringify JSON value`));
        }
        return api.setItem(key, stringVal);
    }
    removeItemAsyncStorage(key, api) {
        return api.removeItem(key);
    }
    clearAllAsyncStorage(api) {
        return api.clear();
    }
    getAllKeysAsyncStorage(api) {
        return api.getAllKeys();
    }
    multiRemoveAsyncStorage(keys, api) {
        return api.multiRemove(keys);
    }
}
// default to window.localStorage
ClientStorage._type = ApiType.LOCAL_STORAGE;
export const storage = new ClientStorage();
